@@ -3,7 +3,7 @@ package Debian::AptContents;
 use strict;
 use warnings;
 
-our $VERSION = '0.106';
+our $VERSION = '0.121';
 
 =head1 NAME
 
@@ -11,7 +11,7 @@ Debian::AptContents - parse/search through apt-file's Contents files
 
 =head1 SYNOPSIS
 
-    my $c = Debian::AptContents->new( { homedir => '~/.dh-make-perl' } );
+    my $c = Debian::AptContents->new( { cache_dir => '~/.cache/dh-make-perl' } );
     my @pkgs = $c->find_file_packages('/usr/bin/foo');
     my $dep = $c->find_perl_module_package('Foo::Bar');
 
@@ -27,7 +27,7 @@ subclass Debian::AptContents, which needs to become more generic.
 use base qw(Class::Accessor);
 __PACKAGE__->mk_accessors(
     qw(
-        cache homedir cache_file contents_files verbose
+        homedir cache cache_dir cache_file contents_files verbose
         source dist
         )
 );
@@ -36,6 +36,7 @@ use Config;
 use Debian::Dependency;
 use DhMakePerl::Utils qw(find_core_perl_dependency is_core_perl_package);
 use File::Spec::Functions qw( catfile catdir splitpath );
+use File::Path qw(make_path);
 use IO::Uncompress::Gunzip;
 use List::MoreUtils qw(uniq);
 use Module::CoreList ();
@@ -52,7 +53,7 @@ our $oldstable_perl = '5.14.2';
 
 =item new
 
-Constructs new instance of the class. Expects at least C<homedir> option.
+Constructs new instance of the class. Expects at least C<cache_dir> option.
 
 =back
 
@@ -60,10 +61,14 @@ Constructs new instance of the class. Expects at least C<homedir> option.
 
 =over
 
-=item homedir
+=item cache_dir
 
 (B<mandatory>) Directory where the object stores its cache.
 
+=item homedir
+
+Legacy option to specify the cache directory.
+
 =item dist
 
 Used for filtering on the C<distributon> part of the repository paths listed in
@@ -76,7 +81,7 @@ Arrayref of F<Contents> file names. Default is to let B<apt-file> find them.
 =item cache_file
 
 Path to the file with cached parsed information from all F<Contents> files.
-Default is F<Contents.cache> under C<homedir>.
+Default is F<Contents.cache> under C<cache_dir>.
 
 =item cache
 
@@ -96,14 +101,18 @@ sub new {
     $class = ref($class) if ref($class);
     my $self = $class->SUPER::new(@_);
 
+    # backwards compatibility
+    $self->cache_dir( $self->homedir )
+        if $self->homedir and not $self->cache_dir;
+
     # required options
-    $self->homedir
-        or die "No homedir given";
+    $self->cache_dir
+        or die "No cache_dir given";
 
     # some defaults
     $self->contents_files( $self->get_contents_files )
         unless $self->contents_files;
-    $self->cache_file( catfile( $self->homedir, 'Contents.cache' ) )
+    $self->cache_file( catfile( $self->cache_dir, 'Contents.cache' ) )
         unless $self->cache_file;
     $self->verbose(1) unless defined( $self->verbose );
 
@@ -419,7 +428,7 @@ sub store_cache {
 
     $dir = catdir( $vol, $dir );
     unless ( -d $dir ) {
-        mkdir $dir
+        make_path( $dir )
             or die "Error creating directory '$dir': $!\n";
     }
 
@@ -465,7 +474,7 @@ Given Perl module name (e.g. Foo::Bar), returns a L<Debian::Dependency> object
 representing the required Debian package and version. If the module is only in perl core,
 a suitable dependency on perl is returned.
 
-For dual-lifed modules, which are in perl and in a separate package, only
+For dual-lived modules, which are in perl and in a separate package, only
 the latter is returned, as the perl package has versioned Provides for them.
 
 =cut
