@@ -16,7 +16,7 @@ package Debian::Control::FromCPAN;
 use strict;
 use warnings;
 
-our $VERSION = '0.106';
+our $VERSION = '0.121';
 
 use Carp qw(croak);
 
@@ -54,11 +54,11 @@ a required module belongs.
 
 =item dpkg_available
 
-An instance of L<DPKG::Parse::Available> to be used when checking whether
+An instance of L<Dpkg::Index> to be used when checking whether
 the locally available package is the required version. For example:
 
-    my $available = DPKG::Parse::Available->new;
-    $available->parse;
+    my $available = Dpkg::Index->new(type => CTRL_INFO_PKG);
+    $available->load("$Dpkg::ADMINDIR/available");
 
 =item dir
 
@@ -116,6 +116,7 @@ sub discover_dependencies {
     my $install_deps = delete $opts->{install_deps};
     my $install_build_deps = delete $opts->{install_build_deps};
     my $wnpp_query = delete $opts->{wnpp_query};
+    my $guess_nocheck = delete $opts->{guess_nocheck};
 
     die "Unsupported option(s) given: " . join( ', ', sort( keys(%$opts) ) )
         if %$opts;
@@ -171,7 +172,7 @@ sub discover_dependencies {
                         . "Automatic find of" 
                         . " dependencies failed. You may want to \n"
                         . "retry using the '--[b]depends[i]' options\n"
-                        . "or just fill the dependency fields in debian/rules"
+                        . "or just fill the dependency fields in debian/control"
                         . " by hand\n";
 
                         return;
@@ -199,12 +200,22 @@ sub discover_dependencies {
                 . join( ", ", @$debs ) . "\n";
         }
         $bin->Depends->add(@$debs);
+
+        # add runtime dependencies to Build-Depends{,-Indep} as well,
+        # as they are most likely needed for tests, but mark
+        # them as '!<nocheck>' like the test dependencies
+        my $r_debs = Debian::Dependencies->new($debs);
+        foreach (@$r_debs) {
+            $_->{profile} = '!nocheck' unless is_core_perl_package($_->{pkg});
+        }
+
         if ( $bin->Architecture eq 'all' ) {
-            $src->Build_Depends_Indep->add(@$debs);
+            $src->Build_Depends_Indep->add(@$r_debs);
         }
         else {
-            $src->Build_Depends->add(@$debs);
+            $src->Build_Depends->add(@$r_debs);
         }
+
         if ($install_deps) {
             foreach my $deb (@$debs) {
                 _install_deb($deb->pkg) unless grep {$deb} @$missing;
@@ -215,33 +226,86 @@ sub discover_dependencies {
     # build-time
     my ( $b_debs, $b_missing ) = $self->find_debs_for_modules(
         {   %{ $deps->{build_requires}     || {} },
-            %{ $deps->{test_requires}      || {} },
             %{ $deps->{configure_requires} || {} }
         },
         $apt_contents,
         $verbose,
         $dpkg_available,
     );
+    push @$missing, @$b_missing;
 
-    if (@$b_debs) {
-        if ($verbose) {
-            print "\n";
-            print "Needs the following debian packages during building: "
-                . join( ", ", @$b_debs ) . "\n";
-        }
-        if ( $self->is_arch_dep ) {
-            $src->Build_Depends->add(@$b_debs);
+    # still build-time but test_requires only
+    my ( $t_debs, $t_missing ) = $self->find_debs_for_modules(
+        {   %{ $deps->{test_requires} || {} }
+        },
+        $apt_contents,
+        $verbose,
+        $dpkg_available,
+    );
+    push @$missing, @$t_missing;
+
+    # add <!nocheck> profile to test dependencies
+    foreach (@$t_debs) {
+        $_->{profile} = '!nocheck' unless is_core_perl_package($_->{pkg});
+    }
+
+    # add <!nocheck> when there are no declared test dependencies
+    # to new as well as existing (on refresh)
+    # build dependencies that are likely to be used only for testing
+    # if Debian::PkgPerl::Util is not available, or the --guess-nocheck option
+    # is not specified, limit only to libtest-*
+    unless (@$t_debs) {
+        if ($guess_nocheck and eval { require Debian::PkgPerl::Util }) {
+            foreach (
+                @$b_debs,
+                @{$src->Build_Depends},
+                @{$src->Build_Depends_Indep}
+                )
+            {
+                $_->{profile} = '!nocheck'
+                    unless Debian::PkgPerl::Util->probable_build_dependency(
+                        $_->{pkg});
+            }
         }
         else {
-            $src->Build_Depends_Indep->add(@$b_debs);
-        }
-        if ($install_build_deps || $install_deps) {
-            _install_deb($_->pkg)
-                foreach @$b_debs;
+            foreach (
+                @$b_debs,
+                @{$src->Build_Depends},
+                @{$src->Build_Depends_Indep}
+                )
+            {
+                $_->{profile} = '!nocheck' if $_->{pkg} =~ /^libtest-/;
+            }
         }
     }
 
-    push @$missing, @$b_missing;
+    if (@$b_debs || @$t_debs) {
+        if ($verbose) {
+            print "\n";
+            print "Needs the following debian packages during building and testing: "
+                . join( ", ", @$b_debs, @$t_debs ) . "\n";
+        }
+        if ( $self->is_arch_dep ) {
+            $src->Build_Depends->add(@$b_debs);
+            $src->Build_Depends->add(@$t_debs);
+        }
+        else {
+            $src->Build_Depends_Indep->add(@$b_debs);
+            $src->Build_Depends_Indep->add(@$t_debs);
+        }
+        if ( $install_build_deps || $install_deps ) {
+            _install_deb( $_->pkg ) foreach ( @$b_debs, @$t_debs );
+        }
+    }
+
+    # s/perl/perl:native/ in Build-Depends
+    if ( $self->is_arch_dep ) {
+        my ($perl) = $src->Build_Depends->remove('perl');
+        if ($perl) {
+            $perl->{pkg} = 'perl:native';
+            $src->Build_Depends->add($perl);
+        }
+    }
 
     if (@$missing) {
         my ($missing_debs_str);
@@ -299,7 +363,7 @@ L<Debian::Dependencies> class) and a list of missing modules.
 
 Installed packages and perl core are searched first, then the APT contents.
 
-If a DPKG::Parse::Available object is passed, also check the available package version
+If a Dpkg::Index object is passed, also check the available package version.
 
 =cut
 
@@ -322,50 +386,9 @@ sub find_debs_for_modules {
 
         my ( $dep, $core_dep, $direct_dep );
 
-        require Debian::DpkgLists;
         if ( my $ver = is_core_module( $module, $version ) ) {
             $core_dep = Debian::Dependency->new( 'perl', $ver );
         }
-        if ( my @pkgs = Debian::DpkgLists->scan_perl_mod($module) ) {
-            # core packages should be included above
-            # it is normal to have them here, in case the version
-            # requirement can't be satisfied by the current perl
-            @pkgs = grep { !is_core_perl_package($_) } @pkgs;
-
-            if (@pkgs) {
-                $direct_dep = Debian::Dependency->new(
-                      ( @pkgs > 1 )
-                    ? [ map { { pkg => $_, ver => $version } } @pkgs ]
-                    : ( $pkgs[0], $version )
-                );
-
-                # Check the actual version available, if we've been passed
-                # a DPKG::Parse::Available object
-                if ( $dpkg_available ) {
-                    my @available;
-                    my @satisfied = grep {
-                        if ( my $pkg = $dpkg_available->get_package('name' => $_) ) {
-                            my $have_pkg = Debian::Dependency->new( $_, '=', $pkg->version );
-                            push @available, $have_pkg;
-                            $have_pkg->satisfies($direct_dep);
-                        }
-                        else {
-                            warn qq(Unable to obtain version information for "$module" with DPKG::Parse::Available. )
-                                .qq(You may need to run "apt-cache dumpavail | dpkg --merge-avail");
-                        }
-                    } @pkgs;
-                    unless ( @satisfied ) {
-                        print "$module is available locally as @available, but does not satisfy $version\n"
-                            if $verbose;
-                        push @missing, $module;
-                    }
-                }
-                else {
-                    warn "DPKG::Parse not available. Not checking version of $module.";
-                }
-            }
-        }
-
         if (!$direct_dep && $apt_contents) {
             $direct_dep = $apt_contents->find_perl_module_package( $module, $version );
 
@@ -374,17 +397,66 @@ sub find_debs_for_modules {
             if ( $direct_dep && $aptpkg_cache ) {
                 my $pkg = $aptpkg_cache->{$direct_dep->pkg};
                 if ( my $available = $pkg->{VersionList} ) {
+                    my $found = 0;
                     for my $v ( @$available ) {
                         my $d = Debian::Dependency->new( $direct_dep->pkg, '=', $v->{VerStr} );
-                        last if $d->satisfies($direct_dep); # exit loop if we have a good version; otherwise:
+
+                        next unless $d->satisfies($direct_dep);
+
+                        $found = 1;
+                        last;
+                    }
+
+                    unless ($found) {
                         push @missing, $module;
-                        print "$module package in APT ($d) does not satisfy $direct_dep"
+                        print "$module packages in APT do not satisfy $direct_dep"
                             if $verbose;
                     }
                 }
             }
         }
 
+        if (!$direct_dep) {
+            require Debian::DpkgLists;
+            if ( my @pkgs = Debian::DpkgLists->scan_perl_mod($module) ) {
+                # core packages should be included above
+                # it is normal to have them here, in case the version
+                # requirement can't be satisfied by the current perl
+                @pkgs = grep { !is_core_perl_package($_) } @pkgs;
+
+                if (@pkgs) {
+                    $direct_dep = Debian::Dependency->new(
+                          ( @pkgs > 1 )
+                        ? [ map { { pkg => $_, ver => $version } } @pkgs ]
+                        : ( $pkgs[0], $version )
+                    );
+
+                    # Check the actual version available, if we've been passed
+                    # a Dpkg::Index object
+                    # (evaluates as "$thing" in boolean context;
+                    # takes 6.5 seconds)
+                    if ( defined $dpkg_available ) {
+                        my @available;
+                        my @satisfied = grep {
+                            if ( my $pkg = $dpkg_available->get_by_key($_) ) {
+                                my $have_pkg = Debian::Dependency->new( $_, '=', $pkg->{Version} );
+                                push @available, $have_pkg;
+                                $have_pkg->satisfies($direct_dep);
+                            }
+                            else {
+                                warn qq(Unable to obtain version information for "$module" with DPKG::Parse::Available. )
+                                    .qq(You may need to run "apt-cache dumpavail | dpkg --merge-avail");
+                            }
+                        } @pkgs;
+                        unless ( @satisfied ) {
+                            print "$module is available locally as @available, but does not satisfy $version\n"
+                                if $verbose;
+                            push @missing, $module;
+                        }
+                    }
+                }
+            }
+        }
 
         $dep = $direct_dep || $core_dep;
         $dep->rel($ver_rel) if $dep and $ver_rel and $dep->ver;
@@ -439,7 +511,7 @@ The following checks are made
 
 =over
 
-=item dependencies on C<perl-modules*>
+=item dependencies on C<perl-modules*> and C<libperl*>
 
 These are replaced with C<perl> as per Perl policy.
 
@@ -461,7 +533,7 @@ if the dependency is redundant.
 
 =item pruned dependency
 
-otherwise. C<perl-modules*> replaced with C<perl>.
+otherwise. C<perl-modules*> and C<libperl*> replaced with C<perl>.
 
 =back
 
@@ -497,7 +569,7 @@ sub prune_simple_perl_dep {
         if $dep->pkg eq 'perl-base' and $unversioned;
 
     # perl is needed in build-dependencies (see Policy 4.2)
-    return $dep if $dep->pkg eq 'perl' and $build;
+    return $dep if $dep->pkg =~ '^perl(:native)?$' and $build;
 
     # unversioned perl non-build-dependency is redundant, because it will be
     # covered by ${perl:Depends}
@@ -546,7 +618,7 @@ sub prune_perl_deps {
     my $self = shift;
 
     # remove build-depending on ancient perl versions
-    for my $perl ( qw( perl perl-base perl-modules ) ) {
+    for my $perl ( qw( perl perl-base perl-modules perl:native ) ) {
         for ( qw( Build_Depends Build_Depends_Indep ) ) {
             my @ess = $self->source->$_->remove($perl);
             # put back non-redundant ones (possibly modified)
@@ -559,7 +631,7 @@ sub prune_perl_deps {
     }
 
     # remove depending on ancient perl versions
-    for my $perl ( qw( perl perl-base perl-modules ) ) {
+    for my $perl ( qw( perl perl-base perl-modules perl:native ) ) {
         for my $pkg ( $self->binary_tie->Values ) {
             for my $rel ( qw(Depends Recommends Suggests) ) {
                 my @ess = $pkg->$rel->remove($perl);
@@ -608,7 +680,7 @@ sub module_name_to_pkg_name {
 
 Copyright (C) 2009, 2010, 2012 Damyan Ivanov L<dmn@debian.org>
 
-Copyright (C) 2019 gregor herrmann L<gregoa@debian.org>
+Copyright (C) 2019, 2020 gregor herrmann L<gregoa@debian.org>
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License version 2 as published by the Free
