@@ -25,7 +25,7 @@ require v5.10.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.106';
+our $VERSION = '0.121';
 
 use base qw( Class::Accessor Tie::IxHash );
 
@@ -58,17 +58,9 @@ See L<https://www.debian.org/doc/debian-policy/#user-defined-fields>.
 
 use constant fields => ();
 
-my %canonical;
-
 sub import {
     my( $class ) = @_;
 
-    # map the accessor name for the lower case equivalent
-    %canonical = map (
-        ( lc($_) => $_ ),
-        $class->fields,
-    );
-
     $class->mk_accessors( $class->fields );
 }
 
@@ -99,6 +91,12 @@ sub new {
     my $class = shift;
     my $init = shift || {};
 
+    # map the accessor name for the lower case equivalent
+    my %canonical = map (
+        ( lc($_) => $_ ),
+        $class->fields,
+    );
+
     my $self = Tie::IxHash->new;
 
     bless $self, $class;
@@ -262,7 +260,7 @@ field.
 sub looks_like_an_x_field {
     my ( $self, $field ) = @_;
 
-    return $field =~ /^X[SBC]?(?:_[A-Z][A-Za-z0-9]*)+$/;
+    return $field =~ /^X[SBC]*(?:_[A-Z][A-Za-z0-9]*)+$/;
 }
 
 =item get($field)
@@ -387,6 +385,8 @@ sub as_string
 
 Copyright (C) 2009, 2017 Damyan Ivanov L<dmn@debian.org>
 
+Copyright (C) 2020 gregor herrmann L<gregoa@debian.org>
+
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License version 2 as published by the Free
 Software Foundation.
