@@ -63,6 +63,8 @@ replaced with underscores.
 
 =item Package_Type
 
+=item Build_Profiles
+
 =back
 
 C<Depends>, C<Conflicts> C<Breaks>, C<Recommends>, C<Suggests>, C<Enhances>,
@@ -93,7 +95,7 @@ package Debian::Control::Stanza::Binary;
 use strict;
 use warnings;
 
-our $VERSION = '0.106';
+our $VERSION = '0.121';
 
 use base 'Debian::Control::Stanza';
 
@@ -101,6 +103,7 @@ use constant fields => qw(
     Package Architecture Section Priority Essential Depends Recommends Suggests
     Enhances Replaces Pre_Depends Conflicts Breaks Provides Built_Using
     Multi_Arch Package_Type Description _short_description _long_description
+    Build_Profiles
 );
 
 =head1 CONSTRUCTOR
