@@ -3,13 +3,13 @@ package Debian::DpkgLists;
 use strict;
 use warnings;
 
-our $VERSION = '0.106';
+our $VERSION = '0.121';
 
 use Cwd;
 
 =head1 NAME
 
-Debian::DpkgLists - scan /var/lib/dpkg/info/*.list for files/patterns
+Debian::DpkgLists - scan dpkg database for files/patterns
 
 =head1 SYNOPSIS
 
@@ -21,13 +21,13 @@ Debian::DpkgLists - scan /var/lib/dpkg/info/*.list for files/patterns
 =head1 DESCRIPTION
 
 B<Debian::DpkgLists> is a module for easy searching of L<dpkg(1)>'s package
-file lists. These are located in F</var/lib/dpkg/info/*.list> and contain a
-simple list of full file names (including the leading slash).
+database which contains a simple list of full file names (including the
+leading slash).
 
 There are a couple of different class methods for searching by full or partial
 path, a regular expression or a Perl module name.
 
-Note that dpkg's file lists represent only dpkg's idea of what is installed on
+Note that dpkg's database represent only dpkg's idea of what is installed on
 the system. If you want to also search in packages, available from the Debian
 archive but not installed locally, see L<Debian::AptContents>.
 
@@ -36,17 +36,29 @@ archive but not installed locally, see L<Debian::AptContents>.
 sub _cat_lists
 {
     my ( $class, $callback ) = @_;
-    while ( defined( my $f = </var/lib/dpkg/info/*.list> ) ) {
-        my $pkg = $f;
-        # e.g. /var/lib/dpkg/info/libdbi-perl:amd64.list
-        $pkg =~ s{^/var/lib/dpkg/info/}{};
-        $pkg =~ s/(?::\w+)?\.list$//;
-        open my $fh, '<', $f or die "open($f): $!\n";
-        while ( defined( my $l = <$fh> ) ) {
-            chomp $l;
-            &$callback( $pkg, $l );
+    my $query_list = 'dpkg-query --show --showformat "\${Package}\n\${db-fsys:Files}"';
+    open( my $fh, '-|', $query_list )
+        or warn "failed to run dpkg-query: $!\n";
+    my ( $pkg, $filename );
+    while ( defined( my $line = <$fh> ) ) {
+        chomp $line;
+        if ( $line =~ /^[a-z0-9]/ ) {    # package names start in first column
+            $pkg = $line;
+            next;
         }
+        elsif ( $line =~ /^ \// ) {      # filenames have a leading space
+            ( $filename = $line ) =~ s/^\s+//;
+        }
+        elsif ( $line =~ /^\(/ ) {       # dpkg-query status messages like "(Reading database ...", localized
+            next;
+        }
+        else {
+            warn "Unrecognized line '$line'\n";
+            next;
+        }
+        &$callback( $pkg, $filename );
     }
+    close($fh);
 }
 
 =head1 CLASS-METHODS
@@ -55,7 +67,7 @@ sub _cat_lists
 
 =item scan_full_path ( I<path> )
 
-Scans dpkg file lists for files, whose full path is equal to I<path>. Use when
+Scans dpkg database for files, whose full path is equal to I<path>. Use when
 you have the full path of the file you want, like C</usr/bin/perl>.
 
 Returns a (possibly empty) list of packages containing I<path>.
@@ -78,7 +90,7 @@ sub scan_full_path
 
 =item scan_partial_path ( I<path> )
 
-Scans dpkg file lists for files, whose full path ends with I<path>. Use when
+Scans dpkg database for files, whose full path ends with I<path>. Use when
 you only care about the file name or other trailing portion of the full path
 like C<bin/perl> (matches C</usr/bin/perl> and C</sbin/perl>).
 
@@ -103,7 +115,7 @@ sub scan_partial_path {
 
 =item scan_pattern ( I<pattern> )
 
-Scans dpkg file lists for files, whose full path matched I<pattern>.
+Scans dpkg database for files, whose full path matches I<pattern>.
 
 Returns a (possibly empty) list of packages containing files whose full path
 matches I<pattern>.
@@ -125,7 +137,7 @@ sub scan_pattern {
 
 =item scan_perl_mod ( I<Module::Name> )
 
-Scans dpkg file lists for files, corresponding to given I<Module::Name>. This
+Scans dpkg database for files, corresponding to given I<Module::Name>. This
 is a shorthand method for L</scan_pattern> with a pattern that matches
 C</Module/Name.pm$> in all directories in C<@INC>.
 
@@ -167,6 +179,8 @@ sub scan_perl_mod {
 
 =item Copyright (C) 2010 Damyan Ivanov <dmn@debian.org>
 
+=item Copyright (C) 2019-2020 gregor herrmann <gregoa@debian.org>
+
 =back
 
 This program is free software; you can redistribute it and/or modify it under
