@@ -2,7 +2,7 @@ package Debian::WNPP::Query;
 use strict;
 use warnings;
 
-our $VERSION = '0.106';
+our $VERSION = '0.121';
 
 =head1 NAME
 
@@ -118,7 +118,7 @@ sub _fetch {
         }
 
         for my $link ( $browser->links ) {
-            next unless $link->url =~ m{^http://bugs.debian.org/(\d+)};
+            next unless $link->url =~ m{^https://bugs.debian.org/(\d+)};
 
             my $bug = $1;
 
