@@ -18,7 +18,7 @@ Version 0.90
 
 =cut
 
-our $VERSION = '0.106';
+our $VERSION = '0.121';
 
 =head1 SYNOPSIS
 
@@ -98,7 +98,7 @@ sub get_apt_contents {
         if $self->apt_contents;
 
     my $apt_c = Debian::AptContents->new(
-        {   homedir      => $self->cfg->home_dir,
+        {   cache_dir    => $self->cfg->cache_dir,
             dist         => $self->cfg->dist,
             verbose      => $self->cfg->verbose,
         }
