@@ -3,7 +3,7 @@ package DhMakePerl::Command::Packaging;
 use strict;
 use warnings;
 
-our $VERSION = '0.106';
+our $VERSION = '0.121';
 
 use feature 'switch';
 
@@ -31,22 +31,25 @@ use Config::INI::Reader ();
 use CPAN ();
 use CPAN::Meta;
 use Cwd qw( getcwd );
+use Dpkg;
+use Dpkg::Index;
+use Dpkg::Control::Types;
 use Debian::Control::FromCPAN;
 use Debian::Dependencies;
 use Debian::Rules;
 use DhMakePerl::PodParser ();
+use Dpkg::Changelog::Debian;
 use Email::Address::XS 1.01;
 use File::Basename qw(basename dirname);
 use File::Find qw(find);
 use File::Path ();
 use File::Which;
 use File::Spec::Functions qw(catfile catpath splitpath);
-use Parse::DebianChangelog;
 use Text::Balanced qw(extract_quotelike);
 use Text::Wrap qw(fill);
 use User::pwent;
 
-use constant debstdversion => '4.4.0';
+use constant debstdversion => '4.6.1';
 
 our %DEFAULTS = (
 );
@@ -151,6 +154,7 @@ sub get_name {
     }
     else {
         $name = $pwnam->gecos;
+        $name =~ s/\n/ /g;
         $name =~ s/,.*//;
     }
     $user ||= $pwnam->name;
@@ -176,9 +180,9 @@ sub fill_maintainer {
             my $old_maint = $src->Maintainer;
             $src->Maintainer($pkg_perl_maint);
             $src->Uploaders->add($old_maint) if $old_maint;
+            $src->Uploaders->add($maint);
         }
 
-        $src->Uploaders->add($maint);
     }
     else {
         $src->Maintainer($maint);
@@ -269,7 +273,7 @@ sub get_wnpp {
     return undef unless $self->cfg->network;
 
     my $wnpp = Debian::WNPP::Query->new(
-        { cache_file => catfile( $self->cfg->home_dir, 'wnpp.cache' ) } );
+        { cache_file => catfile( $self->cfg->cache_dir, 'wnpp.cache' ) } );
     my @bugs = $wnpp->bugs_for_package($package);
     return $bugs[0];
 }
@@ -815,7 +819,7 @@ sub extract_docs {
 
     $dir .= '/' unless $dir =~ m(/$);
 
-    my $toplevelreadme_re = $self->main_dir . '/README(?:\.\w+)?$';
+    my $toplevelreadme_re = quotemeta($self->main_dir) . '/README(?:\.\w+)?$';
     find(
         {   preprocess => sub {
                 my $bn = basename $File::Find::dir;
@@ -892,10 +896,12 @@ sub create_rules {
 
     $self->backup_file($file);
 
-    my $rulesname = 'rules.dh.tiny';
+    my $arch = $self->control->binary_tie->Values(0)->Architecture;
+    my $rulesname
+        = ( $arch eq 'all' ? 'rules.dh.tiny.all' : 'rules.dh.tiny.any' );
 
     for my $source (
-        catfile( $self->cfg->home_dir, $rulesname ),
+        catfile( $self->cfg->config_dir, $rulesname ),
         catfile( $self->cfg->data_dir, $rulesname )
     ) {
         if ( -e $source ) {
@@ -1197,15 +1203,17 @@ sub copyright_from_changelog {
     my ( $self, $firstmaint, $firstyear ) = @_;
     my %maintainers = ();
     @{ $maintainers{$firstmaint} } = ($firstyear);
-    my $chglog = Parse::DebianChangelog->init(
-        { infile => $self->debian_file('changelog') } );
+    my $chglog = Dpkg::Changelog::Debian->new( range => { "all" => 1 } );
+    $chglog->load($self->debian_file('changelog')) or die "Parse error\n";
     my %email_changes = ();
-    foreach ( $chglog->data() ) {
-        my $person      = $_->Maintainer;
-        my $date        = $_->Date;
-        my @date_pieces = split( " ", $date );
-        my $year        = $date_pieces[3];
-        if (my %changes = ($_->Changes =~ m/^\s+\*\sEmail\schange:\s+(.*?)\s+->\s+(.*?)\s*$/xmsg)) {
+    foreach ( @{$chglog} ) {
+        my $person      = $_->get_maintainer();
+        my $year        = $_->get_timepiece()->year;
+        my $changes     = $_->get_part('changes');
+        if (ref $changes eq 'ARRAY') {
+            $changes = join("\n", @$changes);
+        }
+        if (my %changes = ($changes =~ m/^\s+\*\sEmail\schange:\s+(.*?)\s+->\s+(.*?)\s*$/xmsg)) {
             # This way round since we are going backward in time thru changelog
             foreach my $p (keys %changes) {
                 # Parse bare email address; undef if it not an email address
@@ -1367,25 +1375,16 @@ sub discover_dependencies {
         my $wnpp_query;
         $wnpp_query
             = Debian::WNPP::Query->new(
-            { cache_file => catfile( $self->cfg->home_dir, 'wnpp.cache' ) } )
+            { cache_file => catfile( $self->cfg->cache_dir, 'wnpp.cache' ) } )
             if $self->cfg->network;
 
         # control->discover_dependencies needs configured CPAN
         $self->configure_cpan;
 
-        # Attempt to get an instance of DPKG::Parse::Available. If this
-        # isn't available, warn the user, as versions of packages cannot
-        # be checked.
         # Don't cache this in case we've built and installed a
         # module in this instance.
-        my $dpkg_available;
-        if ( eval { require DPKG::Parse::Available } && DPKG::Parse->VERSION >= 0.02 ) {
-            $dpkg_available = DPKG::Parse::Available->new;
-            $dpkg_available->parse;
-        } else {
-            warn "DPKG::Parse v0.02 or higher not found.";
-            warn "Versions of required packages will not be checked.";
-        }
+        my $dpkg_available = Dpkg::Index->new(type => CTRL_INFO_PKG);
+        $dpkg_available->load("$Dpkg::ADMINDIR/available");
 
         return $self->control->discover_dependencies(
             {   dir                => $self->main_dir,
@@ -1397,6 +1396,7 @@ sub discover_dependencies {
                 install_build_deps => $self->cfg->install_build_deps,
                 wnpp_query         => $wnpp_query,
                 intrusive          => $self->cfg->intrusive,
+                guess_nocheck      => $self->cfg->guess_nocheck,
             }
         );
     }
@@ -1471,7 +1471,9 @@ sub discover_utility_deps {
         $build_deps_indep->add('perl');
     }
     else {
-        $build_deps->add('perl');
+        $build_deps->remove('perl');
+        $build_deps->add('perl:native');
+        $build_deps->add('perl-xs-dev');
     }
     $build_deps->add( Debian::Dependency->new( 'debhelper-compat', '=', $debhelper_version ) );
 
@@ -1514,7 +1516,7 @@ sub discover_utility_deps {
         my ($mbt)  = $build_deps_indep->remove('libmodule-build-tiny-perl');
         my ($mbup) = $build_deps_indep->remove('libmodule-build-using-pkgconfig-perl');
         my ($perl) = $build_deps_indep->remove('perl');
-        $perl ||= 'perl';
+        $perl ||= ( $architecture eq 'all' ? 'perl' : 'perl:native' );
         $self->explained_dependency( 'Module::Build', $build_deps,
             "$mb" ) if $mb;
         $self->explained_dependency( 'Module::Build::Tiny', $build_deps,
@@ -1595,7 +1597,8 @@ sub unquote {
 
 =item create_upstream_metadata
 
-Populates F<debian/upstream/metadata> with information from F<META>.
+Populates F<debian/upstream/metadata> with information from F<META>,
+using L<Debian::Upstream::Metadata::Perl>.
 
 =cut
 
@@ -1605,65 +1608,13 @@ sub create_upstream_metadata {
 
     return unless %$meta;
 
-    require YAML::XS;
-
-    my %upstream;
-
-    $upstream{"Archive"}           = 'CPAN';
-    $upstream{"Name"}              = $meta->{name};
-    $upstream{"Contact"}           = join( ', ', @{ $meta->{author} } );
-    # $upstream{"Homepage"}        = $meta->{resources}->{homepage};
-    $upstream{"Bug-Database"}      = $meta->{resources}->{bugtracker}->{web};
-    $upstream{"Bug-Submit"}        = $meta->{resources}->{bugtracker}->{mailto};
-    $upstream{"Repository"}        = $meta->{resources}->{repository}->{url};
-    $upstream{"Repository-Browse"} = $meta->{resources}->{repository}->{web};
-
-    if (defined $upstream{"Repository"}) {
-        my $fix_browse = ! defined $upstream{"Repository-Browse"};
-
-        my $url_parser = qr|(?:([^:/?\#]+):)? # protocol
-                            (?://([^/?\#]*))? # domain name
-                            ([^?\#]*)         # path
-                            (?:\?([^\#]*))?   # query
-                            (?:\#(.*))?       # fragment
-                           |x;
-
-        my ($protocol, $domain, $path, $query, $fragment)
-            = $upstream{"Repository"} =~ $url_parser;
-
-        # fixups:
-        # strip user@, e.g. 'ssh://git@github.com/user/project.git'
-        $domain =~ s|^[^@]+@||;
-        # handle : after host, e.g.'git://git@github.com:user/project.git'
-        if ( $domain =~ m/:/ ) {
-            my ( $domainpart, $userpart ) = split /:/, $domain;
-            $domain = $domainpart;
-            $path   = '/' . $userpart . $path;
-        }
-
-        my $host = {
-            'github.com' => 'github',
-        }->{$domain};
-
-        if ($host eq "github") {
-            if ($protocol ne "https") {
-                $upstream{"Repository"} = "https://$domain$path";
-            }
-            if ($fix_browse) {
-                $path =~ s/\.git$//;
-                $upstream{"Repository-Browse"} = "https://$domain$path";
-            }
-        }
-    }
-
-    foreach ( keys %upstream ) {
-        delete $upstream{$_} unless defined $upstream{$_};
-    }
-
-    my $dir = File::Spec->catdir( $self->main_dir, 'debian', 'upstream' );
-
-    mkdir($dir);
-    YAML::XS::DumpFile( File::Spec->catfile( $dir, 'metadata' ), \%upstream );
+    require Debian::Upstream::Metadata::Perl;
+    Debian::Upstream::Metadata::Perl->convert(
+        $self->meta,
+        File::Spec->catfile(
+            $self->main_dir, 'debian', 'upstream', 'metadata'
+        )
+    );
 }
 
 =item cme_fix_dpkg_control
@@ -1736,7 +1687,7 @@ sub _file_w {
 
 =item Copyright (C) 2006 Frank Lichtenheld <djpig@debian.org>
 
-=item Copyright (C) 2007-2019 gregor herrmann <gregoa@debian.org>
+=item Copyright (C) 2007-2021, gregor herrmann <gregoa@debian.org>
 
 =item Copyright (C) 2007-2013 Damyan Ivanov <dmn@debian.org>
 
