@@ -3,7 +3,7 @@ package DhMakePerl::Utils;
 use strict;
 use warnings;
 
-our $VERSION = '0.106';
+our $VERSION = '0.121';
 
 =head1 NAME
 
@@ -119,7 +119,7 @@ sub find_cpan_distribution {
 =item is_core_perl_package I<package>
 
 Returns true value if the given package is a core Perl package, i.e. one of
-C<perl>, C<perl-base>, C<perl-modules-X.Y> and C<libperlX.Y>.
+C<perl>, C<perl-base>, C<perl-modules-X.Y>, C<libperlX.Y>, and C<perl-xs-dev>.
 
 Having this in a central routine makes it easier to add/remove packages in the
 list.
@@ -133,6 +133,7 @@ sub is_core_perl_package {
     return 1
       if $pkg eq 'perl-base'
       or $pkg eq 'perl'
+      or $pkg eq 'perl-xs-dev'
       or $pkg =~ /^perl-modules(?:-[\d.]+)?$/
       or $pkg =~ /^libperl[\d.]+$/;
     return 0;
